#
# spec file for package stdman
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stdman
Version:        2024.07.05
Release:        1.2
Summary:        C++ stdlib man pages
License:        MIT
Group:          Documentation/Man
URL:            https://github.com/jeaye/stdman
Source0:        https://github.com/jeaye/stdman/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  fdupes
Requires:       man

%description
stdman is a tool that parses archived HTML files from cppreference and
generates groff-formatted manual pages for Unix-based systems. The goal is to
provide excellent formatting for easy readability.

This package provides the full cppreference documentation in the man format.

%prep
%setup -q

%build
%configure

%install
# INSTEAD OF RUNNING make install, WHICH WOULD HAVE INSTALLED GZIP
# COMPRESSED MAN FILES TO MAN DIR, COPY UNCOMPRESSED MAN FILES TO
# man DIR AND LET brp-compress TAKE CARE OF GZIP COMPRESSION.
# brp-compress FREAKS OUT WHEN IT FINDS ALREADY COMPRESSED FILES
# WITH SPECIAL CHARACTERS IN THEM: SEE
# https://bugzilla.opensuse.org/show_bug.cgi?id=1087430
mkdir -p %{buildroot}%{_mandir}/man3
cp -pr ./man/*.3 %{buildroot}%{_mandir}/man3/

%fdupes %{buildroot}%{_mandir}/man3/

%files
%doc README.md
%license LICENSE
%{_mandir}/man3/*.3.gz

%changelog
* Mon Jul  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2024.07.05:
  * Regenerate with v20240610 (unofficial releases).
* Wed Aug 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2022.07.30:
  * Regenerate with v20220730 (from unofficial releases).
* Wed Jul 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2022.02.01:
  * Regenerate with v20220201 (from unofficial releases).
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2021.12.21:
  * Regenerate with cppreference v20201016 (unofficial).
- Reduce wasted space due to duplicated files by using fdupes.
* Wed Dec  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020.11.17:
  * Remove template in html file name (gh#jeaye/stdman#39).
  * Add new groff sections.
* Fri Nov 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2019.08.27:
  * Update to cppreference 20190827.
- Use %%{name}-%%{version} naming scheme for source.
* Thu Mar 29 2018 badshah400@gmail.com
- Instead of running make install, which copies the man files to
  the right dir and compresses them, manually copy the
  uncompressed files to man dir, then let brp-compress take over
  the compression duties. brp-compress freaks out when it sees
  precompressed files with special characters in them sitting in
  the man dir (boo#1087430).
- Drop rpmlintrc file: the duplicated files warning was due to the
  effect of brp-compress as well.
* Thu Mar 29 2018 badshah400@gmail.com
- Initial package.
